@@ -18,14 +18,14 @@ minimap_mode_default = False
 default_reward_args = dict(tag_penalty=-0.2)
 
 
-def parallel_env(map_size=default_map_size, max_cycles=max_cycles_default, minimap_mode=minimap_mode_default, **reward_args):
+def parallel_env(map_size=default_map_size, max_cycles=max_cycles_default, minimap_mode=minimap_mode_default, extra_features=False, **reward_args):
     env_reward_args = dict(**default_reward_args)
     env_reward_args.update(reward_args)
-    return _parallel_env(map_size, minimap_mode, env_reward_args, max_cycles)
+    return _parallel_env(map_size, minimap_mode, env_reward_args, max_cycles, extra_features)
 
 
-def raw_env(map_size=default_map_size, max_cycles=max_cycles_default, minimap_mode=minimap_mode_default, **reward_args):
-    return from_parallel_wrapper(parallel_env(map_size, max_cycles, minimap_mode, **reward_args))
+def raw_env(map_size=default_map_size, max_cycles=max_cycles_default, minimap_mode=minimap_mode_default, extra_features=False, **reward_args):
+    return from_parallel_wrapper(parallel_env(map_size, max_cycles, minimap_mode, extra_features, **reward_args))
 
 
 env = make_env(raw_env)
@@ -71,8 +71,8 @@ def get_config(map_size, minimap_mode, tag_penalty):
 class _parallel_env(magent_parallel_env, EzPickle):
     metadata = {'render.modes': ['human', 'rgb_array'], 'name': "adversarial_pursuit_v2"}
 
-    def __init__(self, map_size, minimap_mode, reward_args, max_cycles):
-        EzPickle.__init__(self, map_size, minimap_mode, reward_args, max_cycles)
+    def __init__(self, map_size, minimap_mode, reward_args, max_cycles, extra_features):
+        EzPickle.__init__(self, map_size, minimap_mode, reward_args, max_cycles, extra_features)
         assert map_size >= 7, "size of map must be at least 7"
         env = magent.GridWorld(get_config(map_size, minimap_mode, **reward_args), map_size=map_size)
 
@@ -80,7 +80,7 @@ class _parallel_env(magent_parallel_env, EzPickle):
         reward_vals = np.array([1, -1, -1, -1, -1] + list(reward_args.values()))
         reward_range = [np.minimum(reward_vals, 0).sum(), np.maximum(reward_vals, 0).sum()]
         names = ["predator", "prey"]
-        super().__init__(env, handles, names, map_size, max_cycles, reward_range, minimap_mode)
+        super().__init__(env, handles, names, map_size, max_cycles, reward_range, minimap_mode, extra_features)
 
     def generate_map(self):
         env, map_size = self.env, self.map_size
